from fastapi import FastAPI, Request, Response
from fastapi.staticfiles import StaticFiles
from requests import request as make_request

from evoprompt.api import backend, config
from evoprompt.api.routers import optimization, runs

app = FastAPI(
    debug=config.DEBUG,
    title="Prompt Optimization Backend",
    lifespan=backend.lifespan,
)
app.include_router(runs.router, prefix="/api/runs")
app.include_router(optimization.router, prefix="/api/optimization")


if config.DEBUG:

    @app.get("/")
    @app.get("/static/{_:path}")
    async def frontent_dev(request: Request):
        response = make_request(
            method=request.method,
            url=f"{request.url.replace(port=3000)}",
            headers=request.headers,
            stream=True,
        )
        return Response(
            content=response.raw.read(),
            status_code=response.status_code,
            headers=dict(response.headers.items()),
        )

else:
    app.mount("/", StaticFiles(directory="frontend/build/", html=True), name="frontend")
